@@ -15,5 +15,5 @@ class Database_Handler:
         return self.handler.insert_row(**keywords)
     
     def update_record(self, keywords):
-        return self.handler.update_record(keywords)
+        return self.handler.update_record(**keywords)
     
\ No newline at end of file
