@@ -216,7 +216,7 @@ class Postgres_Handler:
         } 
         
     #Method to update a SQL row
-    def update_record(self, kwargs):
+    def update_record(self, **kwargs):
         values_dict = {}
         id_key = 'Id'
         clause_section = ''
